@@ -97,19 +97,19 @@ class TestCase(HttpRequest):
         self.end()
         if self.platform in ['android', 'ios']:
             self.driver.stop_app()
-        if self.platform == 'api':
-            method = ResponseResult.method
-            path: str = ResponseResult.path
-            allure.dynamic.title(f'[{method}]{path}')  # 设置用例标题
+        # if self.platform == 'api':
+        #     method = ResponseResult.method
+        #     path: str = ResponseResult.path
+        #     allure.dynamic.title(f'[{method}]{path}')  # 设置用例标题
 
-    @staticmethod
-    def set_title(text):
-        """
-        设置allure报表中对应用例的标题
-        @param text: 测试用例标题
-        @return:
-        """
-        allure.dynamic.title(text)
+    # @staticmethod
+    # def set_title(text):
+    #     """
+    #     设置allure报表中对应用例的标题
+    #     @param text: 测试用例标题
+    #     @return:
+    #     """
+    #     allure.dynamic.title(text)
 
     def el(self, **kwargs):
         """
@@ -193,10 +193,7 @@ class TestCase(HttpRequest):
         doc: https://jmespath.org/
         """
         search_value = jmespath.search(path, ResponseResult.response)
-        if search_value is None:
-            assert path is None, "{} No match".format(path)
-        else:
-            assert search_value == value, f'{search_value} != {value}'
+        assert search_value == value, f'{search_value} != {value}'
 
     def assertLocalPath(self, path, value, json_obj):
         """
@@ -207,10 +204,7 @@ class TestCase(HttpRequest):
         @return:
         """
         search_value = jmespath.search(path, json_obj)
-        if search_value is None:
-            assert path is None, "{} No match".format(path)
-        else:
-            assert search_value == value, f'{search_value} != {value}'
+        assert search_value == value, f'{search_value} != {value}'
 
     def assertLenEq(self, path, value):
         """
@@ -218,10 +212,7 @@ class TestCase(HttpRequest):
         doc: https://jmespath.org/
         """
         search_value = jmespath.search(path, ResponseResult.response)
-        if isinstance(search_value, list):
-            assert len(search_value) == value, f"{search_value} 的长度不等于 {value}"
-        else:
-            raise Exception(f"{search_value} 不是列表")
+        assert len(search_value) == value, f"{search_value} 的长度不等于 {value}"
 
     def assertLenGt(self, path, value):
         """
@@ -229,10 +220,32 @@ class TestCase(HttpRequest):
         doc: https://jmespath.org/
         """
         search_value = jmespath.search(path, ResponseResult.response)
-        if isinstance(search_value, list):
-            assert len(search_value) > value, f"{search_value} 的长度不大于 {value}"
-        else:
-            raise Exception(f"{search_value} 不是列表")
+        assert len(search_value) > value, f"{search_value} 的长度不大于 {value}"
+
+    def assertGt(self, path, value):
+        """
+        值大于多少
+        :param path:
+        :param value:
+        :return:
+        """
+        search_value = jmespath.search(path, ResponseResult.response)
+        assert search_value > value, f"{search_value} 不大于 {value}"
+
+    def assertGe(self, path, value):
+        """
+        值大于等于
+        :param path:
+        :param value:
+        :return:
+        """
+        search_value = jmespath.search(path, ResponseResult.response)
+        assert search_value >= value, f"{search_value} 小于 {value}"
+
+    def assertNotEq(self, path, value):
+        """值不等于"""
+        search_value = jmespath.search(path, ResponseResult.response)
+        assert search_value != value, f"{search_value} 等于 {value}"
 
     def assertIn(self, path, value_list: list):
         """
