@@ -1,23 +1,14 @@
 # @Time    : 2022/2/22 9:35
 # @Author  : kang.yang@qizhidao.com
 # @File    : request.py
-import sys
-
 import requests
 import json as json_util
-
-from requests_toolbelt import MultipartEncoder
-
 from qrunner.utils.config import conf
 from qrunner.utils.log import logger
 
 IMG = ["jpg", "jpeg", "gif", "bmp", "webp"]
 
 
-# class ApiConfig:
-#     login_key = ['accessToken', 'signature']
-
-
 def request(func):
     def wrapper(*args, **kwargs):
         func_name = func.__name__
@@ -27,9 +18,7 @@ def request(func):
             url = list(args)[1]
         except IndexError:
             url = kwargs.get("url", "")
-        # m = func_name.upper()
-        # allure.dynamic.title(f'[{m}]{url}')
-        # allure.dynamic.feature(url.split('/')[1])
+
         ResponseResult.method = func_name.upper()
         ResponseResult.path = url
         base_url = conf.get_name('api', 'base_url')
@@ -54,20 +43,10 @@ def request(func):
                 headers.pop(key)
         # 把上层请求方法的headers参数更新到headers里面
         headers.update(kwargs.pop("headers", {}))
-
-        # headers = kwargs.pop("headers", {})
-        # conf_headers = conf.get_name('api', 'headers')
-        # conf_headers_dict = json_util.loads(conf_headers)
-        # login_status = kwargs.get('login', True)
-        # if conf_headers != 'None':
-        #     if not login_status:
-        #         for key in ApiConfig.login_key:
-        #             conf_headers_dict.pop(key)
-        #     headers.update(conf_headers_dict)
         kwargs['headers'] = headers
 
         # 设置请求超时时间为5s
-        timeout_default = 5
+        timeout_default = int(conf.get_name('api', 'timeout'))
         timeout_set = kwargs.pop("timeout", None)
         if timeout_set is not None:
             kwargs['timeout'] = timeout_set
@@ -79,18 +58,18 @@ def request(func):
         data = kwargs.get("data", "")
         json = kwargs.get("json", "")
         if auth != "":
-            logger.debug(f"[auth]:\n {auth} \n")
+            logger.debug(f"[auth]:\n {json_util.dumps(auth)} \n")
         if headers != "":
             # logger.debug(type(headers))
-            logger.debug(f"[headers]:\n {headers} \n")
+            logger.debug(f"[headers]:\n {json_util.dumps(headers)} \n")
         if cookies != "":
-            logger.debug(f"[cookies]:\n {cookies} \n")
+            logger.debug(f"[cookies]:\n {json_util.dumps(cookies)} \n")
         if params != "":
-            logger.debug(f"[params]:\n {params} \n")
+            logger.debug(f"[params]:\n {json_util.dumps(params)} \n")
         if data != "":
-            logger.debug(f"[data]:\n {data} \n")
+            logger.debug(f"[data]:\n {json_util.dumps(data)} \n")
         if json != "":
-            logger.debug(f"[json]:\n {json} \n")
+            logger.debug(f"[json]:\n {json_util.dumps(json)} \n")
 
         # running function
         r = func(*args, **kwargs)
@@ -100,7 +79,7 @@ def request(func):
         try:
             resp = r.json()
             logger.debug(f"[type]: json \n")
-            logger.debug(f"[response]:\n {resp} \n")
+            logger.debug(f"[response]:\n {json_util.dumps(resp)} \n")
             ResponseResult.response = resp
         except BaseException as msg:
             logger.debug("[warning]: {} \n".format(msg))
@@ -180,16 +159,3 @@ class HttpRequest(object):
                                params, auth, cookies, hooks, json)
         return req
 
-    @staticmethod
-    def file_data(file_path):
-        if 'xlsx' in file_path:
-            data = MultipartEncoder(
-                fields={
-                    "name": 'file',
-                    'file': ('demo.xlsx', open(file_path, 'rb'), 'application/vnd.ms-excel')
-                }
-            )
-        else:
-            print('暂不支持其它文件类型')
-            data = None
-        return data
