@@ -21,7 +21,8 @@ class TestMain(object):
                  rerun='0',
                  concurrent=False,
                  base_url=None,
-                 headers=None
+                 headers=None,
+                 timeout=None
                  ):
         """
         :param platform: 平台，如browser、android、ios、api
@@ -36,6 +37,7 @@ class TestMain(object):
             "accessToken": "xxxx",
             "signature": "xxxx"
         }
+        :@param timeout: 接口请求超时时间
         :@param show_report: 是否在浏览器中打开测试报告
         """
 
@@ -50,6 +52,7 @@ class TestMain(object):
         self.concurrent = concurrent
         self.base_url = base_url
         self.headers = headers
+        self.timeout = timeout
 
         # 将数据写入全局变量
         if self.platform is not None:
@@ -68,7 +71,8 @@ class TestMain(object):
                 sys.exit()
         if self.headers is not None:
             conf.set_name('api', 'headers', json.dumps(self.headers))
-
+        if self.timeout is not None:
+            conf.set_name('api', 'timeout', self.timeout)
 
         # 执行用例
         logger.info('执行用例')
